@@ -8,11 +8,14 @@ import base64
 import random
 import datetime
 import time
+import requests
 from uuid import UUID
 import logging
 
 logger = logging.getLogger(__name__)
 
+_requests_session_instance = None
+
 
 def redact(val, minimum=20):
     total = len(val)
@@ -370,3 +373,22 @@ def debug_imports():
 
     time.sleep(die_sec)
     sys.exit(6)
+
+
+
+
+
+def requests_session():
+    global _requests_session_instance
+    if not _requests_session_instance:
+        _requests_session_instance = requests.Session()
+        # fmt:off
+        headers = {
+              "User-Agent": "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.85 Safari/537.36"
+            , "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9"
+            , "Cache-Control": "no-cache"
+            , "Pragma": "no-cache"
+        }
+        # fmt:on
+        _requests_session_instance.headers.update(headers)
+    return _requests_session_instance
